function [t,xml] = backviterbi(f,par)

% [t,xml] = backviterbi(f,par)
% Restauration step : reverse Viterbi algorithm
% input:
%	f	components density (cell) {N} x [nk,k]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	t    =   hidden states   (cell) {N} x [nk]
%     	xml  =   classification loglikelihood
%
% See also CHAINXPDF

% initializations
% ---------------

N = length(f);		        % sample size 
k = length(par.p);		% number of clusters

t = cell(1,N);
xml = zeros(1,N);

for n = 1:N			% loop on samples	

	nk = size(f{n},1);	% length of nth sequence
	delta = zeros(k,nk);
	psi = zeros(k,nk);

	t{n}=zeros(nk,1);	% hidden states for nth sequence

	% first step
	% ----------
	
	delta(:,nk) = ones(k,1);	

	% propagation 
	% -----------

	for r = nk-1:-1:1		
		[P,S] = max((ones(k,1) * (delta(:,r+1)' .* f{n}(r+1,:))) ...
                           .* par.A,[],2);
                psi(:,r) = S;
		delta(:,r) = P;			      

	end;

	% termination
	% -----------
        
        if all(delta(:,1))
               [xml(n),t{n}(1,1)] = max(log(delta(:,1)) + log(f{n}(1,:)') ...
			     + log(par.p'));
               % likelihood > 0
        else
               [xml(n),t{n}(1,1)] = max(delta(:,1) .* f{n}(1,:)' .* par.p');
               xml(n) = -Inf;
               % likelihood == 0 
        end

	% path backtracking
	% -----------------

	for r = 1:nk-1
		t{n}(r+1,1) = psi(t{n}(r,1),r);
	end	
end
	
	
 
