function [beta,xml] = backward(f,par)

% [beta,xml] = backward(f,par)
% Computation of backward probabilities
% i.e. P(xt+1,...,xn|zt)
% input:
%	f	components density (cell) {N} x [nk,k]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	beta		backward variables (cell) {N} x {nk,k}
%  	xml		likelihood of sample (vector) [N]

% initializations
% ---------------

N = length(f);		        % sample size 
d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

beta = cell(1,N);
% logbeta = cell(1,N);
xml = zeros(1,N);

for n = 1:N			% loop on samples

	nk = size(f{n},1);	% length of nth sequence
	beta{n} = zeros(nk,k);

	% first step
	% ----------
	
	beta{n}(nk,:) = ones(1,k);

	% propagation 
	% -----------

	for t = nk-1:-1:1		
		beta{n}(t,:) = ...
		(f{n}(t+1,:) .* beta{n}(t+1,:)) * (par.A)';
	end;

       % termination
       % -----------

       xml(n) = sum(par.p .* f{n}(1,:) .* beta{n}(1,:));

end;
	
	
 
