function cl = chaincl(z,par,logf)

% cl = chaincl(z,par,logf)
% Computation of complete data (x,z) loglikelihood
% i.e. f(x1,...,xn,z1,...,zn)
% input:
%       z       hidden states (cell) {N} x [nk]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
%	logf	components log density (cell) {N} x [nk,k]
%	
% output:
%
%  	cl     complete data loglikelihood  value [N]
%
% See also CHAINXPDF,CHAINSTATES

% initializations
% ---------------

N = length(logf);		        % sample size 
cl = zeros(N,1);

for n = 1:N			% loop on samples

        nk = size(logf{n},1);   % length of nth chain
        cl(n) = log(par.p(z{n}(1))) + logf{n}(1,z{n}(1));
        for t = 2:nk
	       cl(n) = cl(n) + log(par.A(z{n}(t-1),z{n}(t))) + ...
	                         logf{n}(t,z{n}(t));
        end
end
