function z = chaingibbsinit(par,f)

% z = chaingibbsinit(par,f)
% Initialisation of hidden states for Gibbs sampling
% input:
%	par	        parameters (structure)
%	-.p	        proportions [k]
%	-.mu	        centers [k,d]
%	-.S	        variance matrices [d,d,k]
%	-.A 	        transition matrix [k,k]
%       f               components density (cell) {N} x [nk,k]
% output:
%	z	        random labels (cell) {N} x [nk]

N = length(f);
k = size(f{1},2);		% number of states

for n = 1:N			% loop on the sample
	
	nk = size(f{n},1);  	% length of nth sequence
        p = zeros(nk,k);        % conditionnal state probabilities
	zbin{n} = zeros(nk,k);     % binary labels

        p(1,:) = par.p .* f{n}(1,:);
        p(1,:) = 1/sum(p(1,:)) *  p(1,:);
	unif = rand(nk,1);             % matrix [n,k] of uniform numbers 
				       % on[0,1] 
	cump = cumsum(p(1,:));	       % cumulative sum of p on row 1
	zbin{n}(1,:) = (cumsum(cump >= unif(1),2) == 1);	
				       % binary partition

        for t = 2:nk          % loop on the sequence 

	    % par.A(find(zbin{n}(t-1,:)),:) 
            % f{n}(t,:)
            p(t,:) = f{n}(t,:) .* par.A(find(zbin{n}(t-1,:)),:);	
            p(t,:) = 1/sum(p(t,:)) *  p(t,:);

	    % a posteriori state probabilities
	    
	    cump = cumsum(p(t,:));	   % cumulative sum of p on row t
					   % on[0,1] 
	    zbin{n}(t,:) = (cumsum(cump >= unif(t)) == 1);	
					% binary partition

	    z{n} = bin2lab(zbin{n});
	end;

end
