function z = chaingibbslabel(par,f,zold)

% z = chaingibbslabel(par,f,zold)
% Gibbs sampling of hidden states
% input:
%	par	        parameters (structure)
%	-.p	        proportions [k]
%	-.mu	        centers [k,d]
%	-.S	        variance matrices [d,d,k]
%	-.A 	        transition matrix [k,k]
%       f               components density (cell) {N} x [nk,k]
%	zold  	        current labels (cell) {N} x [nk]
% output:
%	z	        random labels (cell) {N} x [nk]

N = length(f);
k = size(f{1},2);		% number of states

for n = 1:N			% loop on the sample
	
	nk = size(f{n},1);  	% length of nth sequence
        p = zeros(nk,k);        % conditionnal state probabilities
	zbin{n} = zeros(nk,k);     % binary labels

	
	z_old_bin{n} = lab2bin(zold{n});      % binary labels

        p(1,:) = par.p .* f{n}(1,:) .* par.A(:,find(z_old_bin{n}(2,:)))';
	
	while (sum(p(1,:)) == 0)
		zold = chaingibbsinit(par,f);
		z_old_bin{n} = lab2bin(zold{n});
		p(1,:) = par.p .* f{n}(1,:) .* par.A(:,find(z_old_bin{n}(2,:)))';
	end
        p(1,:) = 1/sum(p(1,:)) *  p(1,:);
	unif = rand(nk,1);             % matrix [n,k] of uniform 
	                               % numbers on[0,1] 
	cump = cumsum(p(1,:));	       % cumulative sum of p on row 1
	zbin{n}(1,:) = (cumsum(cump >= unif(1),2) == 1);	
				       % binary partition

        for t = 2:nk-1          % loop on the sequence 

            p(t,:) = f{n}(t,:) .* par.A(find(zbin{n}(t-1,:)),:)...
	    .* par.A(:,find(z_old_bin{n}(t+1,:)))';
	
            p(t,:) = 1/sum(p(t,:)) *  p(t,:);

	    % a posteriori state probabilities
	    
	    cump = cumsum(p(t,:));	   % cumulative sum of p on row t
					   % on[0,1] 
	    zbin{n}(t,:) = (cumsum(cump >= unif(t)) == 1);	
					% binary partition
	end;

        p(nk,:) =  f{n}(nk,:) .* par.A(find(zbin{n}(nk-1,:)),:);
        p(nk,:) = 1/sum(p(nk,:)) *  p(nk,:); 
	cump = cumsum(p(nk,:));	       % cumulative sum of p on row 1
	zbin{n}(nk,:) = (cumsum(cump >= unif(nk),2) == 1);	
				       % binary partition

	z{n} = bin2lab(zbin{n});

end
