function [beta] = condbackward(probx,f,par)

% [beta] = condbackward(probx,f,par)
% Computation of conditionnal backward probabilities
% i.e. P(xt+1,...,xn|zt)|P(xt+1,...,xn|x1,...,xt)
% input:
%       probx	conditionnal probabilities (cell) {N} x [nk]
%		f(xt|x1....xt-1)
%	f	components density (cell) {N} x [nk,d]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	beta		backward variables (cell) {N} x [nk,k]


% initializations
% ---------------

N = length(f);		        % sample size 
k = length(par.p);		% number of clusters

beta = cell(1,N);

for n = 1:N			% loop on samples

	nk = size(f{n},1);	% length of nth sequence
	beta{n} = zeros(nk,k);

	% first step
	% ----------
	
	beta{n}(nk,:) = ones(1,k);

	% propagation 
	% -----------

	for t = nk-1:-1:1		
		beta{n}(t,:) = ...
		(f{n}(t+1,:) .* beta{n}(t+1,:)) * (par.A)';
		beta{n}(t,:) = beta{n}(t,:) / probx{n}(t+1,1);
	end;

	% termination 
	% -----------

	%	beta{n}(1,:) = ...
	%	(f{n}(2,:) .* beta{n}(2,:)') / ((par.p) * f{n}(2,:)');



end;
	
	
 
