function [alpha,probx] = condforward(f,par)

% [alpha,probx] = condforward(f,par)
% Computation of conditionnal forward probabilities
% i.e. P(zt|x1,...,xt)
% input:
%	f	components density (cell) {N} x [nk,k]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	alpha		forward variables (cell) {N} x [nk,k]
%       probx           conditionnal probabilities (cell) {N} x [nk]
%			f(xt|x1....xt-1)
%
% See also CHAINXPDF

% initializations
% ---------------

N = length(f);		        % sample size 
% d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

alpha = cell(1,N);
xml = zeros(1,N);

for n = 1:N			% loop on samples

	nk = size(f{n},1);	% length of nth sequence
	alpha{n} = zeros(nk,k);

	% first step
	% ----------
	
	alpha{n}(1,:) = par.p .* (f{n}(1,:));
        probx{n}(1,1)=sum(alpha{n}(1,:));
        alpha{n}(1,:) = alpha{n}(1,:) /  probx{n}(1,1);

	% propagation 
	% -----------

	for t = 1:nk-1		
		alpha{n}(t+1,:) = ...
		(alpha{n}(t,:) * par.A) .*  (f{n}(t+1,:));
                probx{n}(t+1,1)=sum(alpha{n}(t+1,:));
                alpha{n}(t+1,:) = alpha{n}(t+1,:) /  probx{n}(t+1,1);
	end;

	% termination
	% -----------

	
	% xml(n) = sum(alpha{n}(nk,:));
end
	
	
 
