function A = estimAc(z,z_zsuiv)

% A = estimAc(z,z_zuiv)
% Estimate transition matrix.
% input:
% 	z		conditional probabilities of hidden states
%			(cell) {N} x [nk,k]
%	z_zsuiv		joint conditional probabilities of hidden states
%			(cell) {N} x [k,k,nk]
% output:
%	A		transition matrix [k,k]

N = length(z);		% sample size 
k = size(z{1},2);	% states 

totala = zeros(k,k,N);	
totalz = zeros(k,N);	
% totala ./  totalz = estimated centers for each element in sample

for n = 1:N			% loop on sample
	nk = size(z{n},1);
	totala(:,:,n) = sum(z_zsuiv{n}, 3);
	totalz(:,n) = sum(z{n}(1:nk-1,:), 1)';
end;

S =  sum(totalz,2);

if all(S) 
     A = (diag(1 ./ S)) * sum(totala, 3);
else
     fprintf(1,'\n at least one state unused; can''t estimate transition matrix\n');
     A = [];
end

