function [totalz,O] = estimOc(x,z,v)

% [totalz,O] = estimOc(x,z,v)
% Estimate observation matrix.
% input:
%	x	data: (cell) {N} x [T_n,d] 
% 	z	conditional probabilities of hidden states 
%		(cell) {N} x [Tn,k] 
%	v	number of observed values
% output:
%	O	observation matrix ('np' family) [k,v]
%	totalz	denominators of O(k,:) value [k]

N = length(x);		% sample size 
k = size(z{1},2);	% states 

totalO = zeros(k,v,N);	
totalz = zeros(k,N);	
% totalO ./  totalz = estimated matrix for each element in sample

for n = 1:N			% loop on sample
	Tn = size(z{n},1);	% length of nth sequence
	binx = ((x{n} * ones(1,v)) == (ones(Tn,1)*[1:v]));
	% binary representation of x{n}
	totalO(:,:,n) = (z{n})' * binx;
	totalz(:,n) = (z{n})' * ones(Tn,1);
end

totalz = sum(totalz,2);

if all(totalz)
        O = ((1 ./ totalz) * ones(1,v)) .* sum(totalO,3);
else
	 fprintf(1,'\n at least one state unused; can''t estimate observation matrix\n');
	 O = [];
end


