function S = estimSc(x,mu,z,model,totalz,Sold)

% S = estimSc(x,mu,z,model,totalz,Sold)
% Estimate variance matrices.
% input:
%	x	data (cell) {N} x [nk,d]
%	mu	centers [k,d]
%	z	conditional probabilities of hidden states
%		(cell) {N} x [nk,k]
%	model	model 'plI', 'pklI', 'pklkDAkD', 'plB', etc.
%	totalz	denominators associated with eaxh state [k]
%	Sold	variance matrices of the previous iteration [d,d,k]
% output:
%	S	variance matrices [d,d,k]

N = length(z);
k = size(mu,1);
nk = zeros(k,1);

for n = 1:N,
	  lengths(n)=size(x{n},1);
          nk = nk + sum(z{n},1)';
end

% within cluster scattering matrices
% ----------------------------------

[W,Wk] = scatmatc(x,mu,z);

% estimation depends on the model
% -------------------------------

switch model

  case {'plI','pklI'},			          S = modlI(W,k,sum(lengths));
  case {'plkI','pklkI'},				    S = modlkI(Wk,nk);

  case {'plB','pklB'},				  S = modlB(W,k,sum(lengths));
  case {'plkB','pklkB'},			       S = modlkB(Wk,nk,Sold);
  case {'plBk','pklBk'},			  S = modlBk(Wk,sum(lengths));
  case {'plkBk','pklkBk'},			           S = modlkBk(Wk,nk);

  case {'plC','pklC','plDAD','pklDAD'},		  S = modlC(W,k,sum(lengths));
  case {'plkC','pklkC','plkDAD','pklkDAD'},	       S = modlkC(Wk,nk,Sold);
  case {'plCk','pklCk','plDkAkDk','pklDkAkDk'},	  S = modlCk(Wk,sum(lengths));

  case {'plkCk','pklkCk','plkDkAkDk','pklkDkAkDk'}, 
                                                  S = chainmodlkCk(Wk,totalz);

  case {'plDkADk','pklDkADk'},		       S = modlDkADk(Wk,sum(lengths));

  case {'plkDkADk','pklkDkADk'},	           S = modlkDkADk(Wk,nk,Sold);

  case {'plDAkD','pklDAkD'},		   S = modlDAkD(Wk,sum(lengths),Sold);

  case {'plkDAkD','pklkDAkD'},			    S = modlkDAkD(Wk,nk,Sold);

  otherwise 
	disp('unknown model');
        S = [];
        return;
end
