function p = estimpc(z,model,A)

% p = estimpc(z,model,A)
% Estimate proportions.
% input:
%	z	conditional probabilities of hidden states
%		(cell) {N} x [nk,k]
%	model	model 'plI', 'pklI', 'pklkDAkD', 'plB', etc.
% 	A   	transition matrix [k,k]
% output:
%	p	mixing proportions [k]

k = size(z{1},2);	% states 
N = length(z);		% sample size
p = zeros(1,k);

switch model(1:2)

  case 'pk'			% free proportions
    	for n = 1:N		% loop on sample
		p = p + z{n}(1,:);
	end;
	p =  p / N;
  otherwise
      if (sum(sum(isnan(A))) + sum(sum(isinf(A))) > 0)	
	     p = []; 
    	     fprintf(1,'\nA contains Inf or Nan values\n'); 
    	     return 
      end;
      [V,D] = eig(A');
      D = (diag(D) >= 0.999);               % locates the eigenvalue = 1      
      if ~(sum(D) == 1)
	     p = []; 
    	     fprintf(1,'\nunique stationnary distribution does not exist\n'); 
    	     return 
	else
		V = V * D;              % eigenvector
                p = (V / sum(V,1))';
	end
end
