function [alpha,xml] = forward(f,par)

% [alpha,xml] = forward(f,par)
% Computation of forward probabilities
% i.e. P(x1,...,xt,zt)
% input:
%	f	components density (cell) {N} x [nk,k]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	alpha		forward variables (cell) {N} x {nk,k}
%  	xml		likelihood of sample (vector) [N]

% initializations
% ---------------

N = length(f);		        % sample size 
d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

alpha = cell(1,N);
xml = zeros(1,N);

for n = 1:N			% loop on samples

	nk = size(f{n},1);	% length of nth sequence
	alpha{n} = zeros(nk,k);

	% first step
	% ----------
	
	alpha{n}(1,:) = par.p .* (f{n}(1,:));

	% propagation 
	% -----------

	for t = 1:nk-1		
		alpha{n}(t+1,:) = ...
		(alpha{n}(t,:) * par.A) .*  (f{n}(t+1,:));
	end;

	% termination
	% -----------

	
	xml(n) = sum(alpha{n}(nk,:));
end
	
	
 
