function [z_zsuiv,z] = mcondprob(alpha, beta, probx, par, f);   

%[z_zsuiv,z] = mcondprob(alpha,beta,probx,par,f)   
% Conditional probabilities of hidden states
% P(zt|x1,....xn) and P(zt,zt+1|x1,...,xn)
% input:
%  	alpha		conditionnal forward variables (cell) {N} x {nk,k}
%	beta		conditionnal backward variables 
%                       (cell) {N} x {nk,k}
%       probx           conditionnal probabilities (cell) {N} x [nk]
%			f(xt|x1....xt-1)
%	par     	parameters (structure)
%	-.p     	proportions [k]
%	-.mu     	centers [k,d]
%	-.S     	variance matrices [d,d,k]
%	-.A     	transition matrix [k,k]
%	f	        components density (cell) {N} x [nk,k]
% output:
%	z_zsuiv		joint conditional probabilities of hidden states
%			(cell) {N} x [k,k,nk-1]
%	z		conditional probabilities of hidden states
%			(cell) {N} x [nk,k]

N = length(alpha);		       	% sample size 
k = length(par.p);			% states 

z_zsuiv = cell(1,N);
z = cell(1,N);

for n = 1:N			% loop on samples

	nk = size(alpha{n},1);	% length of nth sequence

	z_zsuiv{n}=zeros(k,k,nk-1);
	z{n} = zeros(k,nk);

	for t = 1:nk-1		% loop on the nth sequence

		z_zsuiv{n}(:,:,t) ...
		= (par.A  ./ (probx{n}(t+1,1) * ones(k,k))) ... 
	        .* ((alpha{n}(t,:))' * ones(1,k)) ...
		.* (ones(k,1) * (beta{n}(t+1,:)  .* f{n}(t+1,:)));
	end;

	z{n} = (alpha{n} .* beta{n});
end;
	
	
		
	

	
