function [z_zsuiv,z] = mcpold(	f, ...
				alpha, ...
				beta, ...
				xml, ...
				par);   

%[z_zsuiv,z] = mcpold(f,alpha,beta,xml)   
% Conditional probabilities of hidden states
% P(zt|x1,....xn) and P(zt,zt+1|x1,...,xn)
% input:
%	f		components density (cell) {N} x [nk,d]
%  	alpha		forward variables (cell) {N} x {nk,k}
%	beta		backward variables (cell) {N} x {nk,k}
%  	xml		likelihood of sample (vector) [N]
% output:
%	z_zsuiv		joint conditional probabilities of hidden states
%			(cell) {N} x [k,k,nk]
%	z		conditional probabilities of hidden states
%			(cell) {N} x [nk,k]

N = length(f);		       		% sample size 
k = length(par.p);			% states 

z_zsuiv = cell(1,N);
z = cell(1,N);

for n = 1:N			% loop on samples

	nk = size(f{n},1);	% length of nth sequence

	z_zsuiv{n}=zeros(k,k,nk-1);
	z{n} = zeros(k,nk);

	for t = 1:nk-1		% loop on the nth sequence

		z_zsuiv{n}(:,:,t) ...
		= (1/xml(n)) * par.A  ...
		.* ((alpha{n}(t,:))' * ones(1,k)) ...
		.* (ones(k,1) * ((beta{n}(t+1,:) .* f{n}(t+1,:))));
	end;

	z{n} = (1/xml(n)) * (alpha{n} .* beta{n});
end;
	
	
		
	

	
