function [W,Wk] = scatmatc(x,mu,z)

% [W,Wk] = scatmatc(x,mu,z)
% Within cluster scattering matrices.
% input:
%	x	data (cell) {N} x [nk,d]
%	mu	centers [k,d]
%	z	conditional probabilities of hidden states
%		(cell) {N} x [nk,k]
% output:
%	W	within cluster scattering matrix [d,d]
%	Wk	scattering matrices for all clusters [d,d,k]

[k,d] = size(mu);		% number of clusters and space dimension
[N] = length(x);	     	% sample size

% scattering matrices for all clusters [d,d,k]
% --------------------------------------------

Wk = zeros(d,d,k);

totalW = zeros(d,d,k,N);
% totalW proportionnal to estimated variances for each element in sample

for n = 1:N			% loop on sample
	nk = size(z{n},1);	% length of nth sequence

	for ik = 1:k

		xminusmuk = x{n} - ones(nk,1) * mu(ik,:);		
	  	% center the sequence: x - muk  
 
		totalW(:,:,ik,n) =  ...
                       (xminusmuk' * diag(z{n}(:,ik))) * xminusmuk;
%		(xminusmuk' .* kron(ones(d,1),z{n}(:,ik)')) * xminusmuk;
	end;
end;


%for ik = 1:k
%	Wk(:,:,ik) = sum(totalW(:,:,ik,:),4);
%end;

Wk = sum(totalW,4);

% within cluster scattering matrix [d,d]
% --------------------------------------

W = sum(Wk,3);
