function [t,xml] = viterbilog(logf,par)

% [t,xml] = viterbilog(f,par)
% Restauration step : MAP algorithm
% input:
%	logf	log components density (cell) {N} x [nk,k]
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]
% output:
%	t    =   hidden states   (cell) {N} x [nk]
%     	xml  =   classification loglikelihood
%
% See also CHAINXPDF

% initializations
% ---------------

N = length(logf);		        % sample size 
k = length(par.p);		% number of clusters
loga = log(par.A);

t = cell(1,N);
xml = zeros(1,N);

for n = 1:N			% loop on samples	

	nk = size(logf{n},1);	% length of nth sequence
	delta = zeros(k,nk);
	psi = zeros(k,nk);

	t{n}=zeros(nk,1);	% hidden states for nth sequence

	% first step
	% ----------
	
	delta(:,1) = (log(par.p))' + (logf{n}(1,:))';	

	% propagation 
	% -----------

	for r = 2:nk		
		[P,S] = max(delta(:,r-1)*ones(1,k) + loga,[],1);
                psi(:,r) = S';
		delta(:,r) = P' + (logf{n}(r,:))';			      

	end;

	% termination
	% -----------

	[xml(n),t{n}(nk,1)] = max(delta(:,nk));

	% path backtracking
	% -----------------

	for r = nk-1:-1:1
		t{n}(r,1) = psi(t{n}(r+1,1),r+1);
	end	
end
	
	
 
