function z = chainrndlabel(beta,f,eml,par)

% z = chainrndlabel(beta,f,eml,par)
% Random labels from the conditional probabilities.
% input:
%	beta		conditionnal backward variables (cell) {N} x [nk,k]
%       f               components density (cell) {N} x [nk,k]
%       eml             likelihood value [n]
%	par	        parameters (structure)
%	-.p	        proportions [k]
%	-.mu	        centers [k,d]
%	-.S	        variance matrices [d,d,k]
%	-.A 	        transition matrix [k,k]
% output:
%	z	        random labels (cell) {N} x [nk]
%
% See also CONDBACKWARD

N = length(beta);
k = size(beta{1},2);		% number of states

for n = 1:N			% loop on the sample
	
	nk = size(beta{n},1);  	% length of nth sequence
        p = zeros(nk,k);        % a posteriori state probabilities
	z{n} = zeros(nk,k);     % binary labels

        p(1,:) = (beta{n}(1,:) .* par.p .* f{n}(1,:)) ...
	          / sum(par.p .* f{n}(1,:));

	unif = rand(nk,1);             % matrix [n,k] of uniform numbers 
				       % on[0,1] 
	cump = cumsum(p(1,:));	       % cumulative sum of p on row 1
	z{n}(1,:) = (cumsum(cump >= unif(1),2) == 1);	
				       % binary partition

        for t = 2:nk          % loop on the sequence 

            p(t,:) = f{n}(t,:) .* beta{n}(t,:) ...
	       .* par.A(find(z{n}(t-1,:)),:);	
            p(t,:) = 1/sum(p(t,:)) *  p(t,:);

	    % a posteriori state probabilities
	    
	    cump = cumsum(p(t,:));	   % cumulative sum of p on row t
					   % on[0,1] 
	    z{n}(t,:) = (cumsum(cump >= unif(t)) == 1);	
					% binary partition
	end;

	z{n} = bin2lab(z{n});			% label partition
end

%if nargin == 2				% zknown supplied ?
%  wherenoNaN = ~isnan(zknown);
%  z(wherenoNaN) = zknown(wherenoNaN);	%  z is equal to zknown where no NaN
%end

