function z = rndlabel(t,zknown)

% z = rndlabel(t[,zknown])
% Random labels from the conditional probabilities.
% input:
%	t	conditional probabilities [n,k]
%	zknown	known labels [n] OPTIONAL
%		(NaN values allowed for unknown labels)
% output:
%	z	random labels [n]  

[n,k] = size(t);		% sample size and number of clusters
cumt = cumsum(t,2);		% cumulative sum of t on each row
unif = rand(n,1)*ones(1,k);	% matrix [n,k] of uniform numbers on [0,1]
z = (cumsum(cumt >= unif,2) == 1);	% binary partition
z = bin2lab(z);			% label partition

if nargin == 2				% zknown supplied ?
  wherenoNaN = ~isnan(zknown);
  z(wherenoNaN) = zknown(wherenoNaN);	%  z is equal to zknown where no NaN
end

