function S = estimS(x,mu,t,model,Sold,nk)

% S = estimS(x,mu,t,model,Sold[,nk])
% Estimate variance matrices.
% input:
% input:
%	x	data [n,d]
%	mu	centers [k,d]
%	t	conditional probabilities [n,k]
%	model	model 'plI', 'pklI', 'pklkDAkD', 'plB', etc.
%	Sold	variance matrices of the previous iteration [d,d,k]
%	nk	sample size of the k clusters [k] OPTIONAL
% output:
%	S	variance matrices [d,d,k]

if nargin == 5
  nk = sum(t,1)';
end
[n,k] = size(t);

% within cluster scattering matrices
% ----------------------------------

[W,Wk] = scatmat(x,mu,t);

% estimation depends on the model
% -------------------------------

switch model

  case {'plI','pklI'},				S = modlI(W,k,n);
  case {'plkI','pklkI'},				S = modlkI(Wk,nk);

  case {'plB','pklB'},				S = modlB(W,k,n);
  case {'plkB','pklkB'},				S = modlkB(Wk,nk,Sold);
  case {'plBk','pklBk'},				S = modlBk(Wk,n);
  case {'plkBk','pklkBk'},				S = modlkBk(Wk,nk);

  case {'plC','pklC','plDAD','pklDAD'},			S = modlC(W,k,n);
  case {'plkC','pklkC','plkDAD','pklkDAD'},		S = modlkC(Wk,nk,Sold);
  case {'plCk','pklCk','plDkAkDk','pklDkAkDk'},		S = modlCk(Wk,n);
  case {'plkCk','pklkCk','plkDkAkDk','pklkDkAkDk'},	S = modlkCk(Wk,nk);

  case {'plDkADk','pklDkADk'},			S = modlDkADk(Wk,n);
  case {'plkDkADk','pklkDkADk'},			S = modlkDkADk(Wk,nk,Sold);
  case {'plDAkD','pklDAkD'},				S = modlDAkD(Wk,n,Sold);
  case {'plkDAkD','pklkDAkD'},			S = modlkDAkD(Wk,nk,Sold);

  otherwise disp('unknown model')

end
