function [D,F] = flury(Wk,A,Dold)

% [D,F] = flury(Wk,A,Dold)
% Minimization of the "F" criterion by Flury's algorithm
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	A	shape matrices [d,d,k]
%	Dold	initial orientation matrix [d,d]
% output:
%	D	final orientation matrix [d,d]
%	F	criterion value

% initializations
% ---------------

[d,d,k] = size(Wk);
q2 = zeros(2,1);
D = Dold;
F = 0;
Fold = -inf;
nbit = 0;

while (abs(F-Fold) > 1e-3) & (nbit < 6)

  Fold = F;
  nbit = nbit + 1;

  for il = 1:d-1
    for im = il+1:d

      % extract the two colums dl and dm
      % --------------------------------
      dl = D(:,il);
      dm = D(:,im);

      % matrix R whom q1 is the 2nd eigenvector
      % ---------------------------------------
      R = zeros(2);
      for ik = 1:k
        R = R + (1/A(il,il,ik) - 1/A(im,im,ik))...
            *[dl dm]'*Wk(:,:,ik)*[dl dm];
      end

      % q1
      % --
      [V,Dvalue] = eig(R);
      [valmin,ivalmin] = min(diag(Dvalue));
      q1 = V(:,ivalmin);

      % q2
      % --
      q2(1) = q1(2);
      q2(2) = -q1(1);

      % replace columns il and im of D
      % ------------------------------
      D(:,il) = [dl,dm]*q1;
      D(:,im) = [dl,dm]*q2;

    end
  end
end

% criterion F
% ------------

F = 0;
for ik = 1:k
  F = F + trace(D*inv(A(:,:,ik))*D'*Wk(:,:,ik));
end
	
