function S = modlDAkD(Wk,n,Sold)

% S = modlDAkD(Wk,n,Sold)
% Variance matrices for the model lDAkD.
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	n	sample size
%	Sold	variance matrices of the previous iteration [d,d,k]
%		(useful to init the iterative procedure)
% output:
%	S	variance matrices [d,d,k]

% NOTE : HERE, A is not necessarily a matrix with diagonal elements
% in the decreasing order

[d,d,k] = size(Wk);

Ak = zeros(d,d,k);
invd = 1/d;

% extract the old matrix D (D=D1=D2=...=Dk)
% -----------------------------------------
% (useful to initialize the "best possible" D

[lold,D,Akold] = decompS(Sold(:,:,1));


% initializations
% ---------------

F = 0;
Fold = -inf;
nbit1 = 0;

% iterative procedure
% -------------------

while (abs(F-Fold) > 1e-3) & (nbit1 < 6)

  Fold = F;
  nbit1 = nbit1 + 1;

  % matrices Ak
  % -----------

  for ik = 1:k
    Mtmp = diag(diag(D'*Wk(:,:,ik)*D));
    Ak(:,:,ik) = Mtmp / (det(Mtmp)^invd);
  end

  % matrix D
  % --------

  [D,F] = flury(Wk,Ak,D);	% Flury's algorithm

end

% volume l
% --------

l = F / (n*d);


% variance matrices S
% -------------------

S = zeros(d,d,k);
for ik = 1:k
  S(:,:,ik) = l*D*Ak(:,:,ik)*D';
end

