function S = modlDkADk(Wk,n)

% S = modlDkADk(Wk,n)
% Variance matrices for the model lDkADk.
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	n	sample size
% output:
%	S	variance matrices [d,d,k]

[d,d,k] = size(Wk);

Dk = zeros(d,d,k);
sumOmk = zeros(d,d);

% compute Dk, extract Omk and sum of Omk
% --------------------------------------

for ik = 1:k

  % decomposition Wk = Lk*Omk*Dk'
  % -----------------------------
  [Dk(:,:,ik),Omktmp,Uktmp] = svd(Wk(:,:,ik));

  % sumOmk
  % ------ 
  sumOmk = sumOmk + Omktmp;

end

% matrix l*A
% ----------

lA = sumOmk / n;

% matrix S
% --------

S = zeros(d,d,k);
for ik = 1:k
  S(:,:,ik) = Dk(:,:,ik)*lA*Dk(:,:,ik)';
end
