function S = modlkC(Wk,nk,Sold)

% S = modlkC(Wk,nk,Sold)
% Variance matrices for the model lkC.
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	nk	sample size of the k clusters [k]
%	Sold	variance matrices of the previous iteration [d,d,k]
%		(useful to init the iterative procedure)
% output:
%	S	variance matrices [d,d,k]

% extract the old matrix C (C=C1=C2=...=Ck)
% -----------------------------------------
% (useful to initialize the "best possible" C

[l,D,A] = decompS(Sold(:,:,1));
C = D*A*D';

% initializations
% ---------------

F = 0;			% current criterion value
Fold = -inf;		% previous criterion value
nbit = 0;		% current iterations number
[d,d,k] = size(Wk);	% space dimension and number of clusters
l = zeros(k,1);		% volumes
invd = 1/d;

% iterative procedure while no convergence and no too much iterations
% -------------------------------------------------------------------

while (abs(F-Fold) > 1e-3) & (nbit < 6)

  Fold = F;
  nbit = nbit + 1;

  % volumes l
  % ---------

  tabtrace = zeros(k,1);
  invC = inv(C);
  for ik = 1:k
    tabtrace(ik) = trace(Wk(:,:,ik)*invC);
    l(ik) =  tabtrace(ik) / (d*nk(ik));
  end

  % matrix C
  % --------

  Mtmp = zeros(d,d);
  for ik = 1:k
    Mtmp = Mtmp + Wk(:,:,ik) / l(ik);
  end
  C = Mtmp / ((det(Mtmp))^invd);

  % criterion
  % ---------

  F = sum(tabtrace ./ l + d * nk .* log(l));

end

% end iterative procedure

% S [d,d,k]
% ---------

S = zeros(d,d,k);
for ik = 1:k
  S(:,:,ik) = l(ik)*C;
end
