function S = modlkDAkD(Wk,nk,Sold)

% S = modlkDAkD(Wk,nk,Sold)
% Variance matrices for the model lkDAkD.
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	nk	sample size of the k clusters [k]
%	Sold	variance matrices of the previous iteration [d,d,k]
%		(useful to init the iterative procedure)
% output:
%	S	variance matrices [d,d,k]

% NOTE : HERE, we have Sk = D*Ak*D' (volume included inside)

[d,d,k] = size(Wk);

Ak = zeros(d,d,k);
detAk = zeros(k,1); % to avoid a loop when computing F
invd = 1/d;

% extract the old matrix D (D=D1=D2=...=Dk)
% -----------------------------------------
% (useful to initialize the "best possible" D

[lold,D,Akold] = decompS(Sold(:,:,1));


% initializations
% ---------------

F = 0;
Fold = -inf;
nbit1 = 0;

% iterative procedure
% -------------------

while (abs(F-Fold) > 1e-3) & (nbit1 < 6)

  Fold = F;
  nbit1 = nbit1 + 1;

  % Ak and detAk
  % ------------

  for ik = 1:k
    Ak(:,:,ik) = diag(diag(D'*Wk(:,:,ik)*D)) / nk(ik);
    detAk(ik) = det(Ak(:,:,ik));
  end

  % matrix D
  % --------

  [D,F] = flury(Wk,Ak,D);	% Flury's algorithm

  % criterion
  % ---------

  F = F + sum(nk .* log(detAk));

end

% matrix S
% --------

S = zeros(d,d,k);
for ik = 1:k
  S(:,:,ik) = D*Ak(:,:,ik)*D';
end
