function S = modlkDkADk(Wk,nk,Sold)

% S = modlkDkADk(Wk,nk,Sold)
% Variance matrices for the model lkDkADk.
% input:
%	Wk	scattering matrices for all clusters [d,d,k]
%	nk	sample size of the k clusters [k]
%	Sold	variance matrices of the previous iteration [d,d,k]
%		(useful to init the iterative procedure)
% output:
%	S	variance matrices [d,d,k]

[d,d,k] = size(Wk);

Dk = zeros(d,d,k);
Omk = zeros(d,d,k);

% extract the old matrix A (A=A1=A2=...=Ak)
% -----------------------------------------
% (useful to initialize the "best possible" A

[lkold,Dkold,A] = decompS(Sold(:,:,1));

% compute Dk's and Omk's
% ----------------------

for ik = 1:k

  % decomposition Wk = Dk*Omk*Dk'
  % -----------------------------
  [Dk(:,:,ik),Omk(:,:,ik),Uktmp] = svd(Wk(:,:,ik));

end

% initializations
% ---------------

F = 0;
Fold = -inf;
nbit = 0;
l = zeros(k,1);
invd = 1/d;

% iterative procedure
% -------------------

while (abs(F-Fold) > 1e-3) & (nbit < 6)

  Fold = F;
  nbit = nbit + 1;

  % lk
  % --

  tabtrace = zeros(k,1);
  invA = inv(A);
  for ik = 1:k
    tabtrace(ik) = trace(Wk(:,:,ik)*Dk(:,:,ik)*invA*Dk(:,:,ik)');
    l(ik) =  tabtrace(ik)/ (d*nk(ik));
  end

  % A
  % -

  Mtmp = zeros(d,d);
  for ik = 1:k
    Mtmp = Mtmp + Omk(:,:,ik) / l(ik);
  end
  A = Mtmp / ((det(Mtmp))^invd);

  % criterion
  % ---------

  F = sum(tabtrace ./ l + d * nk .* log(l));

end

% matrix S
% --------

S = zeros(d,d,k);
for ik = 1:k
  S(:,:,ik) = l(ik)*Dk(:,:,ik)*A*Dk(:,:,ik)';
end



