function KL = normixKL(par,par_ref,n)

% KL = normix(par,par_ref[,n])
% Kullback-Leibler divergence in the normal mixture context.
% input:
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	par_ref	reference parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	n	sample size in the Monte-Carlo estimation: 100^d or value OPTIONAL
% output:
%	KL	Kullback-Leibler divergence

% sample size for the Monte-Carlo simulation
% ------------------------------------------

if nargin < 3			% sample size is not supplied
  d = length(par_ref.mu(1,:));	% space dimension
  n = 100^d;			% sample size
end

% KL divergence
% --------------

x = normixrnd(n,par_ref);			% simulated sample
[f,sumf,logf,logsumf] = normixpdf(x,par);	% mixture density by par
[f,sumf,logf,logsumf_ref] = normixpdf(x,par_ref);	% mixture density by par_ref
KL = mean(logsumf_ref - logsumf);		% KL