function miscla = normixcla(par,n)

% miscla = normixcla(par[,n])
% Estimated theoretical misclassification rate from the normal mixture parameters.
% input:
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	n	sample size for Monte-Carlo estimation OPTIONAL
% output:
%	miscla	theoretical misclassification rate

miscla = 0;

% sample size is supplied ?
% -------------------------

if nargin < 2	% sample size is not supplied
  n = 10000;	% default sample size for Monte-Carlo estimation
end

% estimate miscla
% ---------------

[x,ztrue] = normixrnd(n,par);			% sample
[f,sumf,logf,logsumf] = normixpdf(x,par);	% density of each datum
[t,logt] = condprob(logf,logsumf);		% conditional probabilities
zestim = labels(logt);			% estimated labels
miscla = mean(ztrue ~= zestim);		% error