function df = normixdf(model,k,d,parknown)

% df = normixdf(model,k,d[,parknown])
% Degrees of freedom in the normal model-based.
% input:
%	model	model: 'plI'...
%	k	number of clusters
%	d	space dimension
%	parknown	known parameters (structure) OPTIONAL
%	-.p	proportions: 'unknown' or anything
%	-.mu	centers: 'unknown' or anything
%	-.S	variance matrices: 'unknown' or anything
% output:
%	df	degrees of freedom

% default arguments
% -----------------

if nargin == 3
  parknown.p = 'unknown';
  parknown.mu = 'unknown';
  parknown.S = 'unknown';
end

% unknown centers ?
% -----------------

if strcmp(parknown.mu,'unknown')
  df = k * d;
else
  df = 0;
end;

% proportions
% -----------

if strcmp(model(1:2),'pk') & strcmp(parknown.p,'unknown')
  df = df + k - 1;	% free proportions
end

% variance matrices
% -----------------

if strcmp(parknown.S,'unknown')

  equalvol = 1;			% df for equal volume
  freevol = k;			% df for free volume
  equalorient = d*(d-1)/2;		% df for equal orientation
  freeorient = k * d*(d-1)/2;		% df for free orientation
  equalshape = d - 1;		% df for equal shape
  freeshape = k * (d - 1);		% df for free shape

  switch model

    case {'plI','pklI'},			dfS = equalvol;
    case {'plkI','pklkI'},			dfS = freevol;

    case {'plB','pklB'},			dfS = equalvol + equalshape;
    case {'plkB','pklkB'},			dfS = freevol + equalshape;
    case {'plBk','pklBk'},			dfS = equalvol + freeshape;
    case {'plkBk','pklkBk'},			dfS = freevol + freeshape;

    case {'plC','pklC','plDAD','pklDAD'},	dfS = equalvol + equalshape + equalorient;
    case {'plkC','pklkC','plkDAD','pkklDAD'},	dfS = freevol + equalshape + equalorient;
    case {'plCk','pklCk','plDkAkDk','pklDkAkDk'},	dfS = equalvol + freeshape + freeorient;
    case {'plkCk','pklkCk','plkDkAkDk',...
          'pklkDkAkDk'},			dfS = freevol + freeshape + freeorient;

    case {'plDkADk','pklDkADk'},		dfS = equalvol + equalshape + freeorient;
    case {'plkDkADk','pklkDkADk'},		dfS = freevol + equalshape + freeorient;
    case {'plDAkD','pklDAkD'},		dfS = equalvol + freeshape + equalorient;
    case {'plkDAkD','pklkDAkD'},		dfS = freevol + freeshape + equalorient;

    otherwise disp('unknown model'), dfS = NaN;

  end

  df = df + dfS;	% add df of variance matrices to other df

end
