function parout = normixpinit(parin,k,d,x)

% parout = normixpinit(parin,k,d[,x])
% Initialize normal mixture parameters from parameters specifications.
% input:
%	parin	parameters (structure)
%	-.p	'equal', 'random' or proportions values [k]
%	-.mu	'random' or centers value [k,d]
%	-.S	'identity', 'rand. var.', 'var. x' or variance matrices value [d,d,k]
%       -.O     observation matrix ('np' family) [k,v]
%	k	number of clusters
%	d	space dimension
%	x	data [n,d] (only supplied if parin.mu is 'random')
% output:
%	parout	parameters (structure)
%	-.p	proportions value [k]
%	-.mu	centers value [k,d]
%	-.S	variance matrices value [d,d,k]
%       -.O     observation matrix ('np' family) [k,v]

% proportions
% -----------

parout.p = parin.p;
if isstr(parin.p)
  switch parin.p

    case 'equal', parout.p = ones(k,1) / k;

    case 'random'
      kunif = rand(k,1);		% k uniform numbers
      parout.p = kunif / sum(kunif);	% normalize

    % case 'stationnary'

    otherwise disp('p: unknown value'),parout= [];return 

  end
end

% centers
% -------

parout.mu = parin.mu;
if isstr(parin.mu)
  switch parin.mu

    case 'random',
      [n,d] = size(x);
      if k > n, disp('mu: more centers than data'),parout= [];return,end
      permute = randperm(n);		% permutation of integers 1:n
      parout.mu = x(permute(1:k),:);	% select the k 1st x of this permutation

    case 'none',
      parout.mu = ones(k,d);
         % the value of parout.mu will not be used anyway

    otherwise disp('mu: unknown value'),parout= [];return

  end
end

% variance matrices
% -----------------

parout.S = parin.S;
if isstr(parin.S)
  switch parin.S

    case 'identity', parout.S = repmat(eye(d),[1,1,k]);

    case 'rand. var.'		% random volume for each variance matrix

      rndvar = 10*rand(k,1);
      parout.S = repmat(eye(d),[1,1,k]);
      for ik = 1:k
        parout.S(:,:,ik) = rndvar(ik) * parout.S(:,:,ik);
      end

    case 'var. x'			% same diagonal matrices with variances of sample

      parout.S = repmat(diag(var(x)),[1 1 k]);

    case 'none',
      parout.S = ones(d,d,k);
         % the value of parout.S will not be used anyway

    otherwise disp('S: unknown value'),parout= [];return

  end
end

  
% observation matrices
% -----------------

parout.O = parin.O;
if isstr(parin.O)
  v = max(x(:,1));   % number of observations
  switch parin.O

    case 'random'		% random observation matrix
	parout.O = rand(k,v);
	for i = 1:k
		parout.O(i,:) = parout.O(i,:) / sum(parout.O(i,:),2);
	end;


    case 'none',
       parout.O = ones(k,ceil(v));
         % the value of parout.O will not be used anyway

    otherwise disp('O: unknown value'),parout= [];return

  end

end

  

 
  
  
  
