function parout = normixzinit(zinit,zknown,model,k,x)

% parout = normixzinit(zinit,zknown,model,k,x)
% Initialize normal mixture parameters from partition specifications.
% input:
%	zinit	initial labels: 'random' or value (NaN values possible) [n]
%	zknown	known labels: 'unknown' or value (NaN values possible) [n]
%	model	model: 'plI', ...
%	k	number of clusters
%	x	data [n,d]
% output:
%	parout	parameters (structure)
%	-.p	proportions value [k]
%	-.mu	centers value [k,d]
%	-.S	variance matrices value [d,d,k]

[n,d] = size(x);				% sample size and space dimension

% obtain a partition
% ------------------

if strcmp(zinit,'random')
  zinit = repmat(NaN,[n,1]);			% completly random initial partition
end
if ~strcmp(zknown,'unknown')			% maybe partially known partition
  wherenoNaN = ~isnan(zknown);		% known labels
  zinit(wherenoNaN) = zknown(wherenoNaN);	% affect them to the initial partition
end
tequal = ones(n,k)/k;			% all conditional proba. equal
zinit = lab2bin(rndlabel(tequal,zinit),k);	% random partition with respect of zinit

% obtain associated parameters
% ----------------------------

nk = sum(zinit,1)';				% sample size of each group
if emptycla(nk), parout = []; fprintf(1,'Empty cluster from zinit'); return, end

parout.p = estimp(nk,model);			% associated proportions
parout.mu = estimu(x,zinit,nk);			% associated centers
parout.S = repmat(eye(d),[1 1 k]);			% "previous matrix"
parout.S = estimS(x,parout.mu,zinit,model,parout.S,nk);	% associated variance matrices
