function [W,Wk] = scatmat(x,mu,t)

% [W,Wk] = scatmat(x,mu,t)
% Within cluster scattering matrices.
% input:
%	x	data [n,d]
%	mu	centers [k,d]
%	t	conditional probabilities [n,k]
% output:
%	W	within cluster scattering matrix [d,d]
%	Wk	scattering matrices for all clusters [d,d,k]

[k,d] = size(mu);	% number of clusters and space dimension
[n,d] = size(x);	% sample size

% scattering matrices for all clusters [d,d,k]
% --------------------------------------------

Wk = zeros(d,d,k);

for ik = 1:k

  xminusmuk = x - ones(n,1) * mu(ik,:);		% center the sample: x - muk
  Wk(:,:,ik) = (xminusmuk' * diag(t(:,ik)')) * xminusmuk;

% (xminusmuk' .* kron(ones(d,1),t(:,ik)')) * xminusmuk;

end

% within cluster scattering matrix [d,d]
% --------------------------------------

W = sum(Wk,3);
