function [M1,M2] = diplaytree(vec)

% [M1,M2] = diplaytree(vec)
% displays a (vectorized) hidden tree 
% input:
%	vec	        vectorized tree of wavelet coefficients
% output:
%       M1               matrix of displayed coefficients, root at top
%       M2               matrix of displayed coefficients, root at bottom
%
% Example: 
% [wt,wi,wl]=FWT(x,10,MakeQMF('daubechies',2));
% tree = mktree(wt,wi,wl);
% data = {tree};
% model.k = 2;
% model.fam = 'mbf';
% bestpar = treexem('x',data,'model',model);
% [ttree,tvec,cml] = treestates(data,bestpar,model);
% displaytree(tvec{1});


nb_nodes = length(vec);
nb_scales = log2(nb_nodes+1);
nb_coefs_f = (nb_nodes + 1) / 2;   % number of coefficients at finest scale
M1 = zeros(nb_scales,2*nb_coefs_f);

for scale = 1:nb_scales,
       range = [1:2^scale];
       for pos = 0:2^(nb_scales-scale)-1,
           M1(nb_scales-scale+1, range + pos * 2^scale) = ...
                      vec(2^(nb_scales - scale) + pos);
       end
       M2(scale,:) = M1(nb_scales-scale+1,:);
end



imagesc(M1)
		


