function A = estimAt(z_zsuiv,oldA)

% A = estimAt(z_zuiv,oldA)
% Estimate transition matrix.
% input:
%	z_zsuiv		joint conditional probabilities of hidden states
%			(cell) {N} x [k,k,nk]
%	A		transition matrix [k,k] or cell
% output:
%	A		transition matrix [k,k] or cell 

N = length(z_zsuiv);		% sample size 
k = size(z_zsuiv{1},2);	        % states 
nb_points = size(z_zsuiv{1},3); % tree size

if iscell(oldA)   % several transition matrices
     
     totala = zeros(k,k,nb_points);
     totalz = zeros(nb_points,k,N);

     for t = 1:nb_points,
	
     % z_zsuiv ./  totalz = estimated centers for each element in sample

          for n = 1:N			% loop on sample    
              totala(:,:,t) = totala(:,:,t) + z_zsuiv{n}(:,:,t);
              totalz(t,:,n) = sum(z_zsuiv{n}(:,:,t),2);
          end;

          S =  sum(totalz,3);

          if all(S(t,:)) 
               A{t+1} = (diag(1 ./ S(t,:))) * totala(:,:,t);
          else
               fprintf(1,'\n at least one state unused; can''t estimate transition matrix\n');
               A = []; return
          end

      end         % end for t

else              % one transition matrix

     totala = zeros(k,k,N);	
     totalz = zeros(k,N);	
     % totala ./  totalz = estimated centers for each element in sample

     for n = 1:N			% loop on sample
	   totala(:,:,n) = sum(z_zsuiv{n}, 3);
	   totalz(:,n) = sum(totala(:,:,n),2);
     end;

     S =  sum(totalz,2);

     if all(S) 
          A = (diag(1 ./ S)) * sum(totala, 3);
     else
          fprintf(1,'\n at least one state unused; can''t estimate transition matrix\n');
          A = [];
     end

end % end if
