function [S,H] = estimSHt(x_vec,z)

% [S,H] = estimSHt(x_vec,z)
% Estimate variance matrices.
% Validity : for L2 normalization only
% input:
%       x_vec   data (cell of vectorised trees) {N}
%	z	conditional probabilities of hidden states
%		(cell) {N} x [nk,k]
% output:
%	S	variance matrices [1,1,k]
%	H	scale parameters [k]


% verifier que les z sont bien des nombres

N = length(z);
k = size(z{1},2);
nb_points = length(x_vec{1}(:,1));
nb_scales = log(nb_points + 1) / log(2);

tol = 1e-12;
maxit = 1000;

R2 = zeros(nb_scales,k);
G = zeros(nb_scales,k);

for n = 1:N,
      for scale = 1:nb_scales,
             range = 2^(nb_scales-scale) + [0:2^(nb_scales-scale)-1];
             R2(scale,:) = R2(scale,:) + sum(((x_vec{n}(range,1) .* ...
                        x_vec{n}(range,1)) * ones(1,k)) .* z{n}(range,:),1);
             G(scale,:) = G(scale,:) + sum(z{n}(range,:),1);
      end
end

for i = 1:k,

      C = [1:nb_scales] - ([1:nb_scales] * G(:,i)) / sum(G(:,i));
	 
      sup = 32;
      inf = tol;
      beta = (sup+inf)/2;
      it = 0;

      valpoly = polymbf(R2(:,i),C,beta);

      while ((abs(valpoly) > tol) & (it <= maxit)),
          if valpoly > 0 
              sup = beta;
          else
              inf = beta;
          end
       
          beta = (sup+inf)/2;
          valpoly = polymbf(R2(:,i),C,beta);
          it = it + 1;
      end
      S(:,:,i) = polymbf(R2(:,i),ones(1,nb_scales),beta) / sum(G(:,i));
      H(i) = -0.5 * (log2(beta) + 1);
end




