function [h_states] = hiddentree(x,par)

% [h_states] = hiddentree(x,par)
% Computation of hidden states probabilities
% i.e. P(Si = m)
% input:
%       x	data (cell of trees) {N}
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]  or cell of transition matrices
%       -.H     'unknown' or scale parameter [k]
% output:
%  	h_states   probabilities of hidden states (cell) {N} x [n_N,k]


% initializations
% ---------------

N = length(x);		        % sample size 
k = length(par.p);		% number of clusters

h_states = cell(1,N);
nb_points = length(x{1});

for n = 1:N			% loop on samples

	h_states{n} = zeros(nb_points,k);

	% first step
	% ----------
         
        h_states{n}(1,:) = par.p;

        if iscell(par.A)          % several transition matrices

             for t = 2:nb_points,
		  h_states{n}(t,:) = h_states{n}(x{n}{t}.p,:) * par.A{t};
             end

	else

             for t = 2:nb_points,
		  h_states{n}(t,:) = h_states{n}(x{n}{t}.p,:) * par.A;
             end
	end
end
