function [ttree,pos] = jump2(tree,bestpar,model)

% [ttree,pos] = jump2(tree,bestpar,model)
% hidden states restoration under constraints
% input:
%	tree	tree cell
% 	par	parameters (structure)
% 	-.p	proportions [k]
% 	-.mu	centers [k,d]
% 	-.S	variance matrices [d,d,k]
% 	-.invS	inverse of S [d,d,k] OPTIONAL
% 	-.detS	determinant of S [k] OPTIONAL
% 	-.A	transition matrix [k,k]
% 	model	model and number of clusters (structure)
% 	-.model	model: 'plkCk' or value cell of strings [nbmod]
% 	-.k	number of clusters: n^0.3 or value [nbk]
%       -.A     type of transition matrix : 'full','utriangular' or 
%                'udiagonal'
%       -.fam   family of conditionnal law : 'normal' or 'exp'
%
% output:
%       ttree   restored hidden states (cell of trees)
%       pos     steps of the restoration (index of subtrees) [value]       



pos(1) = 1;          % we start at root
depth = log2(length(tree)+1);

data = {tree};
[ttree,tvec,cml] = treestates(data,bestpar,model);
% hidden states restoration

% pos = [1 2 5];
lb1 = Inf;
lb2 = Inf;
rb1 = Inf;
rb2 = Inf;

for scale = depth-1:-1:1,
      htreetmp1 = setsubtreeto(ttree{1},2*pos(depth-scale),1);
      cl1 = min(treecl(tree,htreetmp1,bestpar,model),lb1);
      htreetmp2 = setsubtreeto(ttree{1},2*pos(depth-scale),2);
      cl2 = min(treecl(tree,htreetmp2,bestpar,model),lb2);
      htreetmp3 = setsubtreeto(ttree{1},2*pos(depth-scale)+1,1);
      cl3 = min(treecl(tree,htreetmp3,bestpar,model),rb1);
      htreetmp4 = setsubtreeto(ttree{1},2*pos(depth-scale)+1,2);
      cl4 = min(treecl(tree,htreetmp4,bestpar,model),rb2);
      [cl,I]=max([cl1 cl2 cl3 cl4]);
      command = strcat('ttree{1} = htreetmp',num2str(I),';');
      eval(command);
      pos(depth-scale+1) = 2*pos(depth-scale) + 1 - floor((I-1)/2);
      displaytree(tree2vec(ttree{1})); 
      command = strcat('print -depsc T',num2str(pos(depth-scale+1)),'.eps');
      eval(command);
      switch I
            case 1, rb1 = -Inf;
            case 2, rb2 = -Inf;
            case 3, lb1 = -Inf;
            case 4, lb2 = -Inf;
      end 
end
