function res = setsubtreeto(tree, root, val)

% res = setsubtreeto(tree, root, val)
% sets all values of the subtree of tree rooted in root
% to the value val
% input:
%	tree	        tree cell
%       root            index value of subtree root
%       val             value to set                
% output:
%       res             tree cell
%
% Example: 
% [wt,wi,wl]=FWT(x,10,MakeQMF('daubechies',2));
% tree = mktree(wt,wi,wl);
% setsubtreeto(tree, 2, 0)

res = tree;

nb_scales = log(length(tree) + 1) / log(2);   % number of scales in tree
root_scale = floor(log(root)/log(2)) + 1; % scale of 'root' in tree
root_scale = nb_scales - root_scale + 1;

for scale = root_scale:-1:1,
    for pos = 0:2^(root_scale-scale)-1,
        res{root*2^(root_scale-scale) + pos}.data = val;
    end
end
