function [alpha] = treecondforward(x,par,beta3,h_states)

% [alpha] = treecondforward(x,par,beta3,h_states)
% Computation of conditionnal forward probabilities
% i.e. P(T1-Ti  | Si = m) / P(T1-Ti  | Ti)
% input:
%       x	   data (cell of trees) {N}
%	par	   parameters (structure)
%	-.p	   proportions [k]
%	-.mu   	   centers [k,d]
%	-.S   	   variance matrices [d,d,k]
%	-.A   	   transition matrix [k,k]  or cell of transition matrices
%       -.H        'unknown' or scale parameter [k]
%	beta3	   backward variables (cell) {N} x [n_N,k]
%  	h_states   probabilities of hidden states (cell) {N} x [n_N,k]
% output:
%	alpha	   conditionnal forward variables (cell) {N} x [n_N,k]


% initializations
% ---------------

N = length(h_states);		        % sample size 
% d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

alpha = cell(1,N);

nb_points = length(h_states{1}(:,1));
nb_scales = log(nb_points + 1) / log(2);

for n = 1:N			% loop on samples

	alpha{n} = zeros(nb_points,k);

	% first step
	% ----------
         
        alpha{n}(1,:) = ones(1,k);;

        if iscell(par.A)          % several transition matrices

	% propagation 
	% -----------
        for scale = nb_scales-1:-1:1
             for pos = 0:2^(nb_scales-scale)-1,
	          t = 2^(nb_scales-scale)+pos;
                  alpha{n}(t,:) = ((alpha{n}(x{n}{t}.p,:)  ...
                          .* beta3{n}(t,:) .* h_states{n}(x{n}{t}.p,:)) ...
                                * par.A{t}) ./ h_states{n}(t,:);
             end
        end    

        else

	% propagation 
	% -----------
        for scale = nb_scales-1:-1:1
             for pos = 0:2^(nb_scales-scale)-1,
	          t = 2^(nb_scales-scale)+pos;
                  alpha{n}(t,:) = ((alpha{n}(x{n}{t}.p,:)  ...
                          .* beta3{n}(t,:) .* h_states{n}(x{n}{t}.p,:)) ...
                                * par.A) ./ h_states{n}(t,:);
             end
        end    

        end	   

end;
