function [z_zsuiv,z] = treecondprobc(alpha, beta2, beta3, x, h_states, par);   

%[z_zsuiv,z] = treecondprobc(alpha, beta2, beta3, x, h_states, par);
% Conditional probabilities of hidden states
% i.e. P(Si = m, Si.parent = n | T1)
% and   P(Si = m | T1)
% input:
%	alpha	   conditional forward variables (cell) {N} x [n_N,k]
%	beta2	   conditional backward variables (cell) {N} x [n_N,k]
%	beta3	   conditional backward variables (cell) {N} x [n_N,k]
%       x	   data (cell of trees) {N}
%  	h_states   probabilities of hidden states (cell) {N} x [n_N,k]
%	par	   parameters (structure)
%	-.p	   proportions [k]
%	-.mu	   centers [k,d]
%	-.S	   variance matrices [d,d,k]
%	-.A	   transition matrix [k,k] or cell of transition matrices
% output:
%	z_zsuiv		joint conditional probabilities of hidden states
%			(cell) {N} x [k,k,n_N]
%	z		conditional probabilities of hidden states
%			(cell) {N} x [n_N,k]

N = size(alpha,2);		       	% sample size 
k = length(par.p);			% states 

z_zsuiv = cell(1,N);
z = cell(1,N);

for n = 1:N			% loop on samples

	nk = size(alpha{n},1);	% length of nth sequence

	z_zsuiv{n}=zeros(k,k,nk);
        % z_zsuiv{n}(k,k,nk) won't be used
 
	z{n} = zeros(k,nk);

        if iscell(par.A)      % several transition matrices

	for t = 2:nk		% loop on the nth sequence

		z_zsuiv{n}(:,:,t) = par.A{t} .*  ...
		((alpha{n}(x{n}{t}.p,:)'  .* beta3{n}(t,:)' .* ...
                 h_states{n}(x{n}{t}.p,:)') * ones(1,k))...
	        .* (ones(k,1) * (beta2{n}(t,:) ./ h_states{n}(t,:)));
	end;

        else

	for t = 2:nk		% loop on the nth sequence

		z_zsuiv{n}(:,:,t) = par.A .*  ...
		((alpha{n}(x{n}{t}.p,:)'  .* beta3{n}(t,:)' .* ...
                 h_states{n}(x{n}{t}.p,:)') * ones(1,k))...
	        .* (ones(k,1) * (beta2{n}(t,:) ./ h_states{n}(t,:)));
	end;

        end

        z_zsuiv{n} = z_zsuiv{n}(:,:,2:nk);
	z{n} = alpha{n} .* beta2{n};
end;
	
	
		
	

	
