function [alpha,xml] = treeforward(f,x,par,beta2,beta3)

% [alpha,xml] = treeforward(f,x,par,beta2,beta3)
% Computation of forward probabilities
% i.e. P(Si = m | T1-Ti)
% input:
%	f	components density (cell) {N} x [nk,k]
%       x	data (cell of trees) {N}
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A	transition matrix [k,k]  or cell of transition matrices
%       -.H     'unknown' or scale parameter [k]
%	beta2	backward variables (cell) {N} x [n_N,k]
%	beta3	backward variables (cell) {N} x [n_N,k]
% output:
%	alpha		forward variables (cell) {N} x [n_N,k]
%  	xml		likelihood of sample (vector) [N]


% initializations
% ---------------

N = size(f,2);		        % sample size 
d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

alpha = cell(1,N);

nb_points = length(f{1}(:,1));
nb_scales = log(nb_points + 1) / log(2);

for n = 1:N			% loop on samples

	alpha{n} = zeros(nb_points,k);
               % beta1{n}(1,:) doesn't mean anything

	% first step
	% ----------
         
        alpha{n}(1,:) = par.p;

        if iscell(par.A)          % several transition matrices

	% propagation 
	% -----------
        for scale = nb_scales-1:-1:1
             for pos = 0:2^(nb_scales-scale)-1,
                  alpha{n}(2^(nb_scales-scale)+pos,:) = ...
                     (alpha{n}(x{n}{2^(nb_scales-scale)+pos}.p,:)  ...
                          .* beta3{n}(2^(nb_scales-scale)+pos,:)) ...
                                * par.A{2^(nb_scales-scale)+pos};
             end
        end    

        else

	% propagation 
	% -----------
        for scale = nb_scales-1:-1:1
             for pos = 0:2^(nb_scales-scale)-1,
                  alpha{n}(2^(nb_scales-scale)+pos,:) = ...
                     (alpha{n}(x{n}{2^(nb_scales-scale)+pos}.p,:)  ...
                          .* beta3{n}(2^(nb_scales-scale)+pos,:)) * par.A;
             end
        end    

        end
	   
        % termination
	% -----------

	       xml(n) = alpha{n}(ceil(nb_points/2),:) * ...
                   beta2{n}(ceil(nb_points/2),:)';

end;
