function [f,logf] = treexmbfpdf(x_vec,par)

% [f,logf] = treexmbfpdf(x_vec,par)
% Normal components and mixture density for mbf model
% Validity : for L2 normalization only
% input: 
%       x_vec   data (cell of vectorised trees) {N}
%	par	parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d] (supposed to be 0 here)
%	-.S	variance matrices [1,1,k]
%	-.A	transition matrix [k,k]
%       -.H     scale parameter [k]
% output:
%	f	components density {N} x [nk,k]
%	logf	log components density {N} x [nk,k]
%

% initializations
% ---------------

N = length(x_vec);		        % sample size 
d = length(par.mu(1,:));
k = length(par.p);		% number of clusters

nb_points = length(x_vec{1}(:,1));
nb_scales = log(nb_points + 1) / log(2);

% logf {N} x [nk,k]
% -----------------

logf = cell(N,1);

for n = 1:N       		       % loop on the elements of sample

   nk = size(x_vec{n},1);	       % length on the sequence
   logf{n} = zeros(nk,k);

   for scale = 1:nb_scales
        range = 2^(nb_scales-scale) + [0:2^(nb_scales-scale)-1];
	for ik = 1:k

  		% v_vec supposed to be centered
  		% xminusmuk(range,:) = x_vec{n}(range,:) - ...
		%     ones(length(range),1) * par.mu(ik,:);

 		 % fast calculus of -0.5 * xminusmuk' * inv(S) * xminusmuk
  		logf{n}(range,ik) =  ...
		    -0.5 * (x_vec{n}(range,:) .* x_vec{n}(range,:)) ...
                    ./ (par.S(ik) * 2^((2 * par.H(ik) + 1) * scale));

  		% log density of the component ik
  		logf{n}(range,ik) =   ... 
		logf{n}(range,ik) -0.5*log(2*pi) - ...
                    0.5*log(par.S(ik) * 2^((2 * par.H(ik) + 1) * scale));
	end % end for ik

   end  % end for scale

   % f {N} x [nk,k] 
   % --------------
   f{n} = exp(logf{n});

end % end for n


