function parout = treexpinit(parin,k,d,x,A,fam,hom)

% parout = treexpinit(parin,k,d,x,A,fam,hom)
% Initialize normal mixture parameters from parameters specifications.
% input:
%	parin	parameters (structure)
%	-.p	'equal', 'random' or probability values [k]
%	-.mu	'random' or centers value [k,d]
%	-.S	'identity', 'rand. var.', 'var. x' or variance matrices 
%                value [d,d,k]
%       -.A     'random' or transition matrix value [k,k]
%       -.H     scale parameter value [k]
%	k	number of clusters
%	d	space dimension
%	x	data (cell of vectorised trees) {N}
%       A       type of transition matrix = [-min,max]
%               min > 0 : first non zero sub-diagonal, 
%               max > 0 : last non zero upper-diagonal (min + max > 2)
%       fam     family of conditionnal law : 'normal' or 'exp' or 'mbf'
%       hom     homogeneity : 'hom' or 'non_hom'
% output:
%	parout	parameters (structure)
%	-.p	initial probability value [k]
%	-.mu	centers value [k,d]
%	-.S	variance matrices value [d,d,k]
%       -.A     transition matrix value [k,k]
%       -.H     scale parameter value [k]



size_allx = 0;


% centers
% -------

parout.mu = parin.mu;
if isstr(parin.mu)
  switch parin.mu

    case 'random',
      N = length(x);
      for n = 1:N 	
	nk = size(x{n},1);		% length of nth sequence
	allx(size_allx + 1:size_allx + nk,:) = x{n};
	size_allx = size_allx + nk;
	if (size_allx > k)
		break;
	end;
       end;
       if k > size_allx , disp('mu: more centers than data'),parout= [];return,end
       
      permute = randperm(size_allx);		% permutation of integers 1:N
      parout.mu = allx(permute(1:k),:);	
	% select the k 1st x of thispermutation

    otherwise disp('mu: unknown value'),parout= [];return

  end
end

% transition matrix
% ------------------

parout.A = parin.A;
if isstr(parin.A)
  switch parin.A

    case 'random',
        switch hom
           case 'hom'
             parout.A = rand(k,k);
	     parout.A = parout.A .* ...
                 (ones(k,k)-tril(ones(k,k),A(1))-triu(ones(k,k),A(2)));
             for i = 1:k
		parout.A(i,:) = parout.A(i,:) / sum(parout.A(i,:),2);
             end;
        
           case 'non_hom'
             parout.A = cell(size(x{1},1)-1,1);
             for t = 2:size(x{1},1),
		   parout.A{t} = rand(k,k);
                   parout.A{t} = parout.A{t} .* ...
		       (ones(k,k)-tril(ones(k,k),A(1))-triu(ones(k,k),A(2)));
                   for i = 1:k,
		       parout.A{t}(i,:) = ...
		          parout.A{t}(i,:) / sum(parout.A{t}(i,:),2);
                   end;
	     end

	  otherwise disp('unknown homogeneity parameter'),parout= [];return

       end     % end switch hom

    otherwise disp('A: unknown value'),parout= [];return

  end      % end switch parin.A
end

% proportions
% -----------

parout.p = parin.p;
if isstr(parin.p)
  switch parin.p

    case 'equal', parout.p = ones(1,k) / k;

    case 'random'
      kunif = rand(1,k);		% k uniform numbers
      parout.p = kunif / sum(kunif);	% normalize

    otherwise disp('p: unknown value'),parout= [];return 

  end
end


% variance matrices
% -----------------

parout.S = parin.S;
if isstr(parin.S)
  switch parin.S

    case 'identity', parout.S = repmat(eye(d),[1,1,k]);

    case 'rand. var.'		% random volume for each variance matrix

      rndvar = 10*rand(k,1);
      parout.S = repmat(eye(d),[1,1,k]);
      for ik = 1:k
        parout.S(:,:,ik) = rndvar(ik) * parout.S(:,:,ik);
      end

    case 'var. x'			% same diagonal matrices with variances of sample
      if (size_allx == 0)
           N = length(x);
	   for n = 1:N 	
                 nk = size(x{n},1);		% length of nth sequence
	         allx(size_allx + 1:size_allx + nk,:) = x{n};
                 size_allx = size_allx + nk;
                 if (size_allx > k)
	        	break;
		 end;
	    end;
       end;
	    
       if (k > size_allx)
	        disp('S: more  variance matrices than data'),parout= [];
                return;
       end

       parout.S = repmat(diag(var(allx)),[1 1 k]);

    otherwise disp('S: unknown value'),parout= [];return

  end
end

  
% scale parameters
% -----------
if strcmp(fam,'mbf')

     parout.H = parin.H;
     if isstr(parin.H)
           if strcmp(parin.H,'random')
                 parout.H = rand(1,k);		% k uniform numbers
	   else 
		 disp('H: unknown value'),parout= [];return
	   end
     end
end

  
