function [totalz,O] = estimOv(x,miss,obs,z,par)

% [totalz,O] = estimOv(x,miss,obs,z,par)
% Estimate observation matrix.
% input:
%	x	data: {N} x [T_n,d] (cell)
%	miss    index of missing values: {N} x [m_n] (cell)
%       obs     index of observed values: {N} x [m_n] (cell)
% 	z	conditional probabilities of hidden states {N} x [Tn,k] (cell)
%	par	current parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%       -.O     observation matrix ('np' family) [k,v]
%	-.A 	transition matrix [k,k]
% output:
%	0	observation matrix ('np' family) [k,v]
%	totalz	denominators of O(k,:) value [k]

N = length(x);		% sample size 
k = size(z{1},2);	% states 
v = size(par.O,2);	% number of values

totalO = zeros(k,v,N);	
totalz = zeros(k,N);	
% totalO ./  totalz = estimated matrix for each element in sample

for n = 1:N			% loop on sample
	Tn = size(z{n},1);	% length of nth sequence
	binx = ((x{n} * ones(1,v)) == (ones(Tn,1)*[1:v]));
	% binary representation of x{n}
	totalO(:,:,n) = (z{n}(obs{n},:))' * binx(obs{n},:);
	totalO(:,:,n) = totalO(:,:,n) ...
		+ ((z{n}(miss{n},:))' * ones(length(miss{n}),v)) .* par.O;
	totalz(:,n) = (z{n})' * ones(Tn,1);
end;

totalz = sum(totalz,2);

if all(totalz)
        O = ((1 ./ totalz) * ones(1,v)) .* (sum(totalO,3));
else
	 fprintf(1,'\n at least one state unused; can''t estimate observation matrix\n');
	 O = [];
end


