function S = estimSv(x,miss,obs,z,model,totalz,muold,par)

% S = estimSv(x,miss,obs,mu,z,model,totalz,par)
% Estimate variance matrices.
% input:
%	x	data: {N} x [Tn,d] (cell)
%	miss	index of missing values: {N} x [m_n] (cell)
%	obs	index of observed values: {N} x [m_n] (cell)
%	z	conditional probabilities of hidden states [N,k]
%	model	model 'plI', 'pklI', 'pklkDAkD', 'plB', etc.
%	totalz	denominators associated with each state: value [k]
%	muold	centers of the previous iteration [d,d,k]
%	par	current parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A 	transition matrix [k,k]
% output:
%	S	variance matrices [d,d,k]

N = length(z);
k = size(muold,1);
Tn = zeros(k,1);

for n = 1:N,
	  lengths(n)=size(x{n},1);
          Tn = Tn + sum(z{n},1)';
end

% within cluster scattering matrices
% ----------------------------------

[W,Wk] = scatmatv(x,z,miss,obs,muold,par);

% estimation depends on the model
% -------------------------------

switch model

  case {'plI','pklI'},			          S = modlI(W,k,sum(lengths));
  case {'plkI','pklkI'},				    S = modlkI(Wk,Tn);

  case {'plB','pklB'},				  S = modlB(W,k,sum(lengths));
  case {'plkB','pklkB'},			       S = modlkB(Wk,Tn,par.S);
  case {'plBk','pklBk'},			  S = modlBk(Wk,sum(lengths));
  case {'plkBk','pklkBk'},			           S = modlkBk(Wk,Tn);

  case {'plC','pklC','plDAD','pklDAD'},		  S = modlC(W,k,sum(lengths));
  case {'plkC','pklkC','plkDAD','pklkDAD'},	       S = modlkC(Wk,Tn,par.S);
  case {'plCk','pklCk','plDkAkDk','pklDkAkDk'},	  S = modlCk(Wk,sum(lengths));

  case {'plkCk','pklkCk','plkDkAkDk','pklkDkAkDk'}, 
                                                  S = chainmodlkCk(Wk,totalz);

  case {'plDkADk','pklDkADk'},		       S = modlDkADk(Wk,sum(lengths));

  case {'plkDkADk','pklkDkADk'},	           S = modlkDkADk(Wk,Tn,par.S);

  case {'plDAkD','pklDAkD'},		   S = modlDAkD(Wk,sum(lengths),par.S);

  case {'plkDAkD','pklkDAkD'},			    S = modlkDAkD(Wk,Tn,par.S);

  otherwise 
	disp('unknown model');
        S = [];
        return;
end
