function [totalz,mu] = estimuv(x,miss,obs,z,par)

% [totalz,mu] = estimuv(x,miss,obs,z,par)
% Estimate centers.
% input:
%	x	data: {N} x [T_n,d] (cell)
%	miss    index of missing values: {N} x [m_n] (cell)
%       obs     index of observed values: {N} x [m_n] (cell)
% 	z	conditional probabilities of hidden states {N} x [Tn,k] (cell)
%	par	current parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A 	transition matrix [k,k]
% output:
%	mu	centers  value [k,d]
%	totalz	denominators of mu(k,:) value [k]

N = length(x);		% sample size 
d = size(x{1},2);	% dimension of data
k = size(z{1},2);	% states 

totalmu = zeros(k,d,N);	
totalz = zeros(k,N);	
missdiagz = zeros(k,k);
% totalmu ./  totalz = estimated centers for each element in sample

for n = 1:N			% loop on sample
	Tn = size(z{n},1);	% length of nth sequence
        missdiagz = missdiagz + diag(sum(z{n}(miss{n},:),1));
	totalmu(:,:,n) = (z{n}(obs{n},:))' * x{n}(obs{n},:);
	totalz(:,n) = (z{n})' * ones(Tn,1);
end;

totalz = sum(totalz,2);
missmu = missdiagz * par.mu;

if all(totalz)
        mu = ((1 ./ totalz) * ones(1,d)) .* ...
                             (sum(totalmu,3) + missmu);
else
	 fprintf(1,'\n at least one state unused; can''t estimate centers\n');
	 mu = [];
end


