function [W,Wk] = scatmatv(x,z,miss,obs,muold,par)

% [W,Wk] = scatmatv(x,z,miss,obs,muold,par)
% Within cluster scattering matrices for models with 
% non observed data
% input:
%	x	data [N,d]
%	z	conditional probabilities of hidden states [N,k]
%       miss    index of missing values: value [m]
%       obs     index of observed values: value [m]
%	muold	centers of the previous iteration [d,d,k]
%	par	current parameters (structure)
% output:
%	W	within cluster scattering matrix [d,d]
%	Wk	scattering matrices for all clusters [d,d,k]
%
% See also ESTIMSV

[k,d] = size(muold);		% number of clusters and space dimension
[N] = length(x);	     	% sample size

% scattering matrices for all clusters [d,d,k]
% --------------------------------------------

for n = 1:N			% loop on sample

        [W,totalW(:,:,:,n)] = scatmat(x{n}(obs{n},:),par.mu,z{n}(obs{n},:));

        missz = sum(z{n}(miss{n},:),1);
        % sum of components in z due to missing values

        for ik = 1:k
               totalW(:,:,ik,n) = (missz(ik) * (par.S(:,:,ik) + ...
		       (muold(ik,:) - par.mu(ik,:)) ...
		       * (muold(ik,:) - par.mu(ik,:))') + totalW(:,:,ik,n));
        end
end

Wk = sum(totalW,4);

% within cluster scattering matrix [d,d]
% --------------------------------------

W = sum(Wk,3);
