function [t,cml] = valstates(x,par,model,miss)

% [t,cml] = valstates(x,par,model,miss)
% Restauration step via MAP algorithm          
% input:
%	x	data (cell) {N} x [n_N,d]
%	miss	index of missing values: {N} x [m_N] (cell)
%	par     parameters (structure)
%	-.p	proportions [k]
%	-.mu	centers [k,d]
%	-.S	variance matrices [d,d,k]
%	-.A   	transition matrix [k,k]
%	model	model and number of clusters (structure)
%	-.model	model: 'plkCk' or value cell of strings [nbmod]
%	-.k	number of clusters: n^0.3 or value [nbk]
%       -.A     type of transition matrix : 'full','utriangular' or 
%               'udiagonal'
%       -.fam   family of conditionnal law : 'normal' or 'exp'
% output:
%       t    =   hidden states   (cell) {N} x [nk]
%       cml  =   classification loglikelihood   
%


k = length(par.p);		% number of states
N = length(x);                  % sample size

  % conditional probabilities
  % ----------------------------------

  [f,logf] = valxpdf(x,miss,par,model);        % density
			   % density
       for n = 1:N
            if (~all(f{n}))
                par = [];
		xml = -Inf;
		fprintf(1,' At least one element of sample has conditionnal probability zero');
		return
	    end	
	end

    
    % classification step
    % -------------------

   if (all(par.A))
           % viterbilog should be more accurate than viterbi
           % but requires A > 0
          [t,cml] = viterbilog(logf,par);     % map
   else
	  par.A = par.A + eps * ones(size(par.A));
          for i = 1:size(par.A,1)
               par.A(i,:) = par.A(i,:)./ sum(par.A(i,:));
	  end
	  [t,cml] = viterbilog(logf,par);
   end;
