function argout = valxarg(argin)

% argout = valxarg(argin)
% Control arguments of valxem.
% input:
%	argin	user arguments
% output:
%	argout	transformed arguments

% make structure array
% --------------------

if ~isempty(argin)				% some arguments are present
  nameargout = argin(1:2:end);		% get names of arguments
  valargout = argin(2:2:end);			% get values of arguments
  argout = cell2struct(valargout,nameargout,2);	% structure array
else
  argout = {};
end

% data
% ----

if ~isfield(argout,'x')
     error('data x needed')
end
N = length(argout.x);	 % sample size

% missing observations
% --------------------

if ~isfield(argout,'miss')
     argout.miss = [];   % default missing observations: none
end

% parknown default value
% ----------------------

if ~isfield(argout,'parknown') 	        % all structure not exist
  argout.parknown = [];
end
if ~isfield(argout.parknown,'p')	% proportions not defined
  argout.parknown.p = 'unknown';
end
if ~isfield(argout.parknown,'mu')	% centers not defined
  argout.parknown.mu = 'unknown';
end
if ~isfield(argout.parknown,'O')	% observation matrix not defined
  argout.parknown.O = 'unknown';
end
if ~isfield(argout.parknown,'S')	% variance matrices not defined
  argout.parknown.S = 'unknown';
end
if ~isfield(argout.parknown,'A')	% transition matrix not defined
  argout.parknown.A = 'unknown';
end

% init default value
% ------------------
   
     argout.init = 'parameters';

% parinit default value
% ---------------------

if ~isfield(argout,'parinit')		% all structure not exist
  argout.parinit = [];
end
if ~isfield(argout.parinit,'p')	% proportions not defined
  argout.parinit.p = 'stationnary';
end
if ~isfield(argout.parinit,'mu')	% centers not defined
   if (isfield(argout.model,'fam') & strcmp(argout.model.fam,'np'))  
	argout.parinit.mu = 'none';
	argout.parknown.mu = 'none';
   else		
	argout.parinit.mu = 'random';
	argout.parinit.O = 'none';
	argout.parknown.O = 'none';
   end
end
if ~isfield(argout.parinit,'S')	% variance matrices not defined
     if (~isfield(argout.model,'fam') | strcmp(argout.model.fam,'normal'))
          argout.parinit.S = 'var. x';
     else
          % no covariance matrix needed
          argout.parinit.S = 'none';
          argout.parknown.S = 'none';
     end
end
if ~isfield(argout.parinit,'O')	% observation matrix not defined
     if (isfield(argout.model,'fam') & strcmp(argout.model.fam,'np'))
          argout.parinit.O = 'random';
	  argout.parinit.mu = 'none';
	  argout.parinit.S = 'none';
	  argout.parknown.mu = 'none';
	  argout.parknown.S = 'none';
     else
          % no observation matrix needed
          argout.parinit.O = 'none';
          argout.parknown.O = 'none';
     end
end
if ~isfield(argout.parinit,'A')	% transition matrix not defined
  argout.parinit.A = 'random';
end


% nbxem default value
% -------------------

if ~isfield(argout,'nbxem')				% if nbxem not exist
  if ((strcmp(argout.init,'parameters') & ...		% and random parameters
       (strcmp(argout.parinit.p,'random') | ...
        strcmp(argout.parinit.mu,'random') | ...
        strcmp(argout.parinit.S,'random var.') | ...
        strcmp(argout.parinit.O,'random') | ...
	strcmp(argout.parinit.A,'random'))))
    argout.nbxem = 5;				% then nbxem is 5
  else
    argout.nbxem = 1;				% else nbxem is 1
  end
end

% convergence default value
% -------------------------

if ~isfield(argout,'cvg')
  argout.cvg = 'xmlORmaxit';			% default value
end
if iscell(argout.cvg) & (length(argout.cvg)==1)
  argout.cvg = argout.cvg{1};
end

if ~iscell(argout.cvg)			        % replicate cvg 1 time
  tmp = argout.cvg;				% in a cell
  argout.cvg = cell(1,1);
  argout.cvg = tmp;
end

% maxit default value
% -------------------

if ~isfield(argout,'maxit')				% if maxit not exist
  if strcmp(argout.parknown.p,'unknown') | ...		% unknown parameters
     strcmp(argout.parknown.mu,'unknown') | ...
     strcmp(argout.parknown.S,'unknown') | ...
     strcmp(argout.parknown.O,'unknown') | ...
     strcmp(argout.parknown.A,'unknown')
    argout.maxit = 500;				% then maxit is 500
  else
    argout.maxit = 1;				% else maxit is 1
  end
end
if length(argout.maxit)==1			% replicate maxit 1 time
  argout.maxit = argout.maxit + zeros(1,1);
end


% maxfail default value
% ---------------------

if ~isfield(argout,'maxfail')
  argout.maxfail = 5;
end

% saveit default value
% --------------------

if ~isfield(argout,'saveit')
  argout.saveit = 'no';
end

% model default value
% -------------------

if ~isfield(argout,'model')			% all structure not exist
  argout.model = [];
end
if ~isfield(argout.model,'model')		% model not defined
  argout.model.model = 'plkCk';
end
if ~isfield(argout.model,'fam')		        % family not defined
  argout.model.fam = 'normal';
end
if ~isfield(argout.model,'k')			% number of clusters not defined
  if ~strcmp(argout.parknown.p,'unknown')		% p is known
    argout.model.k = length(argout.parknown.p);		% obtain it from this p
  elseif ~strcmp(argout.parknown.mu,'unknown')		% mu is known
    argout.model.k = length(argout.parknown.mu(:,1));	% obtain it from this mu
  elseif ~strcmp(argout.parknown.O,'unknown')		% O is known
    argout.model.k = length(argout.parknown.O(:,1));	% obtain it from this O
  elseif ~strcmp(argout.parknown.S,'unknown')		% S is known
    argout.model.k = length(argout.parknown.S(1,1,:));	% obtain it from this S
  elseif ~isstr(argout.parinit.p)			% p initial is supplied
    argout.model.k = length(argout.parinit.p);		% obtain it from this p
  elseif ~isstr(argout.parinit.mu)			% mu initial is supplied
    argout.model.k = length(argout.parinit.mu(:,1));	% obtain it from this mu
  elseif ~isstr(argout.parinit.O)			% O initial is supplied
    argout.model.k = length(argout.parinit.O(:,1));	% obtain it from this O
  elseif ~isstr(argout.parinit.S)			% S initial is supplied
    argout.model.k = length(argout.parinit.S(1,1,:));	% obtain it from this S
  elseif ~isstr(argout.parinit.A)			% A initial is supplied
    argout.model.k = length(argout.parinit.A(1,:));	% obtain it from this A
  else
    argout.model.k = ceil(N^0.3);		% default value for k
  end
end
if ~isfield(argout.model,'A')		        % type of transition matrix   
                                                % not defined
    for k = 1:length(argout.model.k),
      argout.model.A{k} = [-1*argout.model.k(k), argout.model.k(k)]; 
    end
           % full model by default
    else
    if ~iscell(argout.model.A)
     argout.model.A = num2cell(repmat(argout.model.A,...
				      length(argout.model.k),...
				      1), ...
			       2);
      % model.A is a cell: [-2 2] -> {[-2 2]}
       end
end

if ~iscell(argout.model.model)
     argout.model.model = {argout.model.model};
     % model is a cell: 'plI' -> {'plI'}
end
